==> pyrnnoise-0.2.1-py3-none-manylinux1_x86_64.whl: pyrnnoise-0.2.1.data/purelib/pyrnnoise/frame_queue.py <==
# Copyright (c) 2024, Zhendong Peng (pzd17@tsinghua.org.cn)
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import numpy as np
import soxr


class FrameQueue:
    def __init__(self, frame_size_samples, sample_rate, channels):
        self.frame_size_samples = frame_size_samples
        self.remained_samples = np.empty((0, channels))
        if sample_rate != 48000:
            self.rs = soxr.ResampleStream(sample_rate, 48000, channels)
        self.sample_rate = sample_rate

    def add_chunk(self, chunk, last=False):
        if self.sample_rate != 48000:
            chunk = self.rs.resample_chunk(chunk, last)
        self.remained_samples = np.concatenate((self.remained_samples, chunk))
        while len(self.remained_samples) >= self.frame_size_samples:
            frame = self.remained_samples[: self.frame_size_samples]
            self.remained_samples = self.remained_samples[len(frame) :]
            yield frame, len(frame)

        if last and len(self.remained_samples) > 0:
            frame = self.remained_samples
            pad_frame = np.pad(
                frame, ((0, self.frame_size_samples - len(frame)), (0, 0))
            )
            yield pad_frame, len(frame)

==> pyrnnoise-0.2.7-py3-none-manylinux1_x86_64.whl: pyrnnoise-0.2.7.data/purelib/pyrnnoise/frame_queue.py <==
# Copyright (c) 2024, Zhendong Peng (pzd17@tsinghua.org.cn)
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import numpy as np
import soxr


class FrameQueue:
    def __init__(self, frame_size_samples, sample_rate, channels):
        self.frame_size_samples = frame_size_samples
        self.remained_samples = np.empty((0, channels), dtype=np.float32)
        if sample_rate != 48000:
            self.rs = soxr.ResampleStream(sample_rate, 48000, channels)
        self.sample_rate = sample_rate

    def add_chunk(self, chunk, last=False):
        if self.sample_rate != 48000:
            chunk = self.rs.resample_chunk(chunk, last)
        self.remained_samples = np.concatenate((self.remained_samples, chunk))
        while len(self.remained_samples) > self.frame_size_samples:
            frame = self.remained_samples[: self.frame_size_samples]
            self.remained_samples = self.remained_samples[len(frame) :]
            yield frame, False

        if last and len(self.remained_samples) > 0:
            yield self.remained_samples, True
